## What's Changed

### 新增

- 支持自定义插件源。
- 支持飞书（Lark）的 Webhook 模式（将事件推送至开发者服务器）。
- 支持 “禁用自带指令” 快捷配置项，启用后将禁用所有 AstrBot 自带指令。入口： WebUI -> 配置文件 -> 平台配置。

### 优化

- 从 WebUI 移除了开发版本渠道。
- 当试图测试"Agent Runner"时，提示前往配置文件页测试。
- WebUI 列表项支持批量粘贴、回车创建项目。

### 修复

- Gemini API 部分调用失败的问题。
- WebUI 插件安装加载 Dialog 关闭按钮在手机端下显示异常的问题。
- 部分情况下，WebUI 日志显示不全的问题。